pub fn tool_correlation(
event: &ControlEvent,
source: &ProviderSource,
provider_tool_id: &str,
) -> StringExpand description
Correlation id of one provider tool call carried by event.
pub fn tool_correlation(
event: &ControlEvent,
source: &ProviderSource,
provider_tool_id: &str,
) -> StringCorrelation id of one provider tool call carried by event.